@@ -12,7 +12,7 @@ urlpatterns = patterns('',
     url(r'^index/?$', IndexView.as_view(), name="index"),
     url(r'^about/?$', AboutView.as_view(), name="about"),
     url(r'^admin/', include(admin.site.urls)),
-    url(r'^bootstrap/?$', include('events.urls'))
+    url(r'^sponsors/?$', include('mittun.sponsors.urls')),
 )
 
 urlpatterns += staticfiles_urlpatterns()
